DeleteMessage class

Implemented types

Properties

baseMessage → LogicalReplicationMessageTypes
The message type
latefinal
hashCode → int
The hash code for this object.
no setterinherited
oldTuple ↔ TupleData
NewTuple is the contents of a new tuple. Byte1('N'): Identifies the following TupleData message as a new tuple.
latefinal
oldTupleType ↔ DeleteMessageTuple
OldTupleType Byte1('K'): Identifies the following TupleData submessage as a key. This field is optional and is only present if the update changed data in any of the column(s) that are part of the REPLICA IDENTITY index.
latefinal
relationId ↔ int
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited