FieldDescription class

Constructors

FieldDescription.read(PgByteDataReader reader)
factory

Properties

columnOid → int
final
fieldName → String
final
formatCode → int
final
hashCode → int
The hash code for this object.
no setterinherited
isBinaryEncoding → bool
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableOid → int
final
typeModifier → int
final
typeOid → int
final
typeSize → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited