UnknownLogicalReplicationMessage class

A non-stnadard message for unkown messages

This message only holds the bytes as data.

Implemented types

Properties

bytes → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited