run<R> abstract method
Obtains a PgSession capable of running statements and calls fn with
it.
Returns the result (either the value or an error) of invoking fn. No
updates will be reverted in the event of an error.
Implementation
Future<R> run<R>(Future<R> Function(PgSession session) fn);